@@ -1,9 +1,6 @@
 """Objects for nodes."""
 
-__all__ = [
-    "Node",
-    "Nodes",
-]
+__all__ = ["Node", "Nodes"]
 
 from collections import Sequence
 import typing
@@ -18,25 +15,19 @@ from . import (
     ObjectType,
     to,
 )
-from ..enum import (
-    NodeType,
-    PowerState,
-)
+from ..enum import NodeType, PowerState
 
 
 def normalize_hostname(hostname):
     """Strips the FQDN from the hostname, since hostname is unique in MAAS."""
     if hostname:
-        return hostname.split('.', 1)[0]
+        return hostname.split(".", 1)[0]
     return hostname
 
 
 def map_tag_name_to_dict(instance, value):
     """Convert a tag name into a dictionary for Tag."""
-    return {
-        'name': value,
-        '__incomplete__': True
-    }
+    return {"name": value, "__incomplete__": True}
 
 
 class NodesType(ObjectType):
@@ -51,8 +42,7 @@ class NodesType(ObjectType):
         params = {}
         if hostnames:
             params["hostname"] = [
-                normalize_hostname(hostname)
-                for hostname in hostnames
+                normalize_hostname(hostname) for hostname in hostnames
             ]
         data = await cls._handler.read(**params)
         return cls(map(cls._object, data))
@@ -74,29 +64,25 @@ class Node(Object, metaclass=NodeTypeMeta):
     """A node stored in MAAS."""
 
     domain = ObjectFieldRelated("domain", "Domain")
-    fqdn = ObjectField.Checked(
-        "fqdn", check(str), readonly=True)
-    hostname = ObjectField.Checked(
-        "hostname", check(str), check(str))
+    fqdn = ObjectField.Checked("fqdn", check(str), readonly=True)
+    hostname = ObjectField.Checked("hostname", check(str), check(str))
     interfaces = ObjectFieldRelatedSet("interface_set", "Interfaces")
     ip_addresses = ObjectField.Checked(  # List[str]
-        "ip_addresses", check(Sequence), readonly=True)
-    node_type = ObjectField.Checked(
-        "node_type", to(NodeType), readonly=True)
+        "ip_addresses", check(Sequence), readonly=True
+    )
+    node_type = ObjectField.Checked("node_type", to(NodeType), readonly=True)
     owner = ObjectFieldRelated("owner", "User")
-    power_state = ObjectField.Checked(
-        "power_state", to(PowerState), readonly=True)
+    power_state = ObjectField.Checked("power_state", to(PowerState), readonly=True)
     power_type = ObjectField.Checked("power_type", check(str))
     pool = ObjectFieldRelated("pool", "ResourcePool", use_data_setter=True)
-    system_id = ObjectField.Checked(
-        "system_id", check(str), readonly=True, pk=True)
+    system_id = ObjectField.Checked("system_id", check(str), readonly=True, pk=True)
     tags = ObjectFieldRelatedSet(
-        "tag_names", "Tags", reverse=None, map_func=map_tag_name_to_dict)
+        "tag_names", "Tags", reverse=None, map_func=map_tag_name_to_dict
+    )
     zone = ObjectFieldRelated("zone", "Zone")
 
     def __repr__(self):
-        return super(Node, self).__repr__(
-            fields={"system_id", "hostname"})
+        return super(Node, self).__repr__(fields={"system_id", "hostname"})
 
     def as_machine(self):
         """Convert to a `Machine` object.
@@ -104,8 +90,7 @@ class Node(Object, metaclass=NodeTypeMeta):
         `node_type` must be `NodeType.MACHINE`.
         """
         if self.node_type != NodeType.MACHINE:
-            raise ValueError(
-                'Cannot convert to `Machine`, node_type is not a machine.')
+            raise ValueError("Cannot convert to `Machine`, node_type is not a machine.")
         return self._origin.Machine(self._data)
 
     def as_device(self):
@@ -114,8 +99,7 @@ class Node(Object, metaclass=NodeTypeMeta):
         `node_type` must be `NodeType.DEVICE`.
         """
         if self.node_type != NodeType.DEVICE:
-            raise ValueError(
-                'Cannot convert to `Device`, node_type is not a device.')
+            raise ValueError("Cannot convert to `Device`, node_type is not a device.")
         return self._origin.Device(self._data)
 
     def as_rack_controller(self):
@@ -125,10 +109,13 @@ class Node(Object, metaclass=NodeTypeMeta):
         `NodeType.REGION_AND_RACK_CONTROLLER`.
         """
         if self.node_type not in [
-                NodeType.RACK_CONTROLLER, NodeType.REGION_AND_RACK_CONTROLLER]:
+            NodeType.RACK_CONTROLLER,
+            NodeType.REGION_AND_RACK_CONTROLLER,
+        ]:
             raise ValueError(
-                'Cannot convert to `RackController`, node_type is not a '
-                'rack controller.')
+                "Cannot convert to `RackController`, node_type is not a "
+                "rack controller."
+            )
         return self._origin.RackController(self._data)
 
     def as_region_controller(self):
@@ -138,11 +125,13 @@ class Node(Object, metaclass=NodeTypeMeta):
         `NodeType.REGION_AND_RACK_CONTROLLER`.
         """
         if self.node_type not in [
-                NodeType.REGION_CONTROLLER,
-                NodeType.REGION_AND_RACK_CONTROLLER]:
+            NodeType.REGION_CONTROLLER,
+            NodeType.REGION_AND_RACK_CONTROLLER,
+        ]:
             raise ValueError(
-                'Cannot convert to `RegionController`, node_type is not a '
-                'region controller.')
+                "Cannot convert to `RegionController`, node_type is not a "
+                "region controller."
+            )
         return self._origin.RegionController(self._data)
 
     async def get_power_parameters(self):
@@ -151,20 +140,22 @@ class Node(Object, metaclass=NodeTypeMeta):
         return data
 
     async def set_power(
-            self, power_type: str,
-            power_parameters: typing.Mapping[str, typing.Any] = {}):
+        self, power_type: str, power_parameters: typing.Mapping[str, typing.Any] = {}
+    ):
         """Set the power type and power parameters for this node."""
         data = await self._handler.update(
-            system_id=self.system_id, power_type=power_type,
-            power_parameters=power_parameters)
-        self.power_type = data['power_type']
+            system_id=self.system_id,
+            power_type=power_type,
+            power_parameters=power_parameters,
+        )
+        self.power_type = data["power_type"]
 
     async def save(self):
         # the resource pool uses the name in the API, not the id. The field is
         # defined with use_data_setter=True, so the value in self._changed_data
         # is the full data dict, not just the id.
-        if 'pool' in self._changed_data:
-            self._changed_data['pool'] = self._changed_data['pool']['name']
+        if "pool" in self._changed_data:
+            self._changed_data["pool"] = self._changed_data["pool"]["name"]
         return await super().save()
 
     async def delete(self):
